@@ -8,6 +8,7 @@ from sqlalchemy_declarative_extensions.dialects.query import (
     get_role_cls,
     get_roles,
     get_schemas,
+    get_view,
     get_views,
 )
 
@@ -20,6 +21,7 @@ __all__ = [
     "get_role_cls",
     "get_roles",
     "get_schemas",
+    "get_view",
     "get_views",
     "mysql",
     "postgresql",
